@@ -31,7 +31,6 @@ import com.sun.source.tree.Tree;
 import com.sun.source.util.TreePath;
 import com.sun.tools.javac.code.*;
 import com.sun.tools.javac.code.Symbol.RecordComponent;
-import com.sun.tools.javac.comp.AttrContext;
 import com.sun.tools.javac.comp.Env;
 import com.sun.tools.javac.tree.JCTree.*;
 import com.sun.tools.javac.tree.JCTree.JCPolyExpression.*;
@@ -647,13 +646,13 @@ public class TreeInfo {
 
     /** The end position of given tree, given  a table of end positions generated by the parser
      */
-    public static int getEndPos(JCTree tree, EndPosTable endPosTable) {
+    public static int getEndPos(JCTree tree) {
         if (tree == null)
             return Position.NOPOS;
 
-        int mapPos = endPosTable.getEndPos(tree);
-        if (mapPos != Position.NOPOS)
-            return mapPos;
+        int endpos = tree.endpos;
+        if (endpos != Position.NOPOS)
+            return endpos;
 
         switch(tree.getTag()) {
             case BITOR_ASG: case BITXOR_ASG: case BITAND_ASG:
@@ -673,57 +672,57 @@ public class TreeInfo {
             case COMPL:
             case PREINC:
             case PREDEC:
-                return getEndPos(((JCOperatorExpression) tree).getOperand(RIGHT), endPosTable);
+                return getEndPos(((JCOperatorExpression) tree).getOperand(RIGHT));
             case CASE:
-                return getEndPos(((JCCase) tree).stats.last(), endPosTable);
+                return getEndPos(((JCCase) tree).stats.last());
             case CATCH:
-                return getEndPos(((JCCatch) tree).body, endPosTable);
+                return getEndPos(((JCCatch) tree).body);
             case CONDEXPR:
-                return getEndPos(((JCConditional) tree).falsepart, endPosTable);
+                return getEndPos(((JCConditional) tree).falsepart);
             case FORLOOP:
-                return getEndPos(((JCForLoop) tree).body, endPosTable);
+                return getEndPos(((JCForLoop) tree).body);
             case FOREACHLOOP:
-                return getEndPos(((JCEnhancedForLoop) tree).body, endPosTable);
+                return getEndPos(((JCEnhancedForLoop) tree).body);
             case IF: {
                 JCIf node = (JCIf)tree;
                 if (node.elsepart == null) {
-                    return getEndPos(node.thenpart, endPosTable);
+                    return getEndPos(node.thenpart);
                 } else {
-                    return getEndPos(node.elsepart, endPosTable);
+                    return getEndPos(node.elsepart);
                 }
             }
             case LABELLED:
-                return getEndPos(((JCLabeledStatement) tree).body, endPosTable);
+                return getEndPos(((JCLabeledStatement) tree).body);
             case MODIFIERS:
-                return getEndPos(((JCModifiers) tree).annotations.last(), endPosTable);
+                return getEndPos(((JCModifiers) tree).annotations.last());
             case SYNCHRONIZED:
-                return getEndPos(((JCSynchronized) tree).body, endPosTable);
+                return getEndPos(((JCSynchronized) tree).body);
             case TOPLEVEL:
-                return getEndPos(((JCCompilationUnit) tree).defs.last(), endPosTable);
+                return getEndPos(((JCCompilationUnit) tree).defs.last());
             case TRY: {
                 JCTry node = (JCTry)tree;
                 if (node.finalizer != null) {
-                    return getEndPos(node.finalizer, endPosTable);
+                    return getEndPos(node.finalizer);
                 } else if (!node.catchers.isEmpty()) {
-                    return getEndPos(node.catchers.last(), endPosTable);
+                    return getEndPos(node.catchers.last());
                 } else {
-                    return getEndPos(node.body, endPosTable);
+                    return getEndPos(node.body);
                 }
             }
             case WILDCARD:
-                return getEndPos(((JCWildcard) tree).inner, endPosTable);
+                return getEndPos(((JCWildcard) tree).inner);
             case TYPECAST:
-                return getEndPos(((JCTypeCast) tree).expr, endPosTable);
+                return getEndPos(((JCTypeCast) tree).expr);
             case TYPETEST:
-                return getEndPos(((JCInstanceOf) tree).pattern, endPosTable);
+                return getEndPos(((JCInstanceOf) tree).pattern);
             case WHILELOOP:
-                return getEndPos(((JCWhileLoop) tree).body, endPosTable);
+                return getEndPos(((JCWhileLoop) tree).body);
             case ANNOTATED_TYPE:
-                return getEndPos(((JCAnnotatedType) tree).underlyingType, endPosTable);
+                return getEndPos(((JCAnnotatedType) tree).underlyingType);
             case ERRONEOUS: {
                 JCErroneous node = (JCErroneous)tree;
                 if (node.errs != null && node.errs.nonEmpty())
-                    return getEndPos(node.errs.last(), endPosTable);
+                    return getEndPos(node.errs.last());
             }
         }
         return Position.NOPOS;
@@ -740,8 +739,8 @@ public class TreeInfo {
             public JCTree getTree() { return tree; }
             public int getStartPosition() { return TreeInfo.getStartPos(tree); }
             public int getPreferredPosition() { return endPos; }
-            public int getEndPosition(EndPosTable endPosTable) {
-                return TreeInfo.getEndPos(tree, endPosTable);
+            public int getEndPosition() {
+                return TreeInfo.getEndPos(tree);
             }
         };
     }
