@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2025, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2026, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -24,39 +24,47 @@
  */
 
 /*
+ * UNICODE LICENSE V3
+ *
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
+ * Copyright © 1991-2025 Unicode, Inc.
  *
- * Permission is hereby granted, free of charge, to any person obtaining
- * a copy of the Unicode data files and any associated documentation
- * (the "Data Files") or Unicode software and any associated documentation
- * (the "Software") to deal in the Data Files or Software
- * without restriction, including without limitation the rights to use,
- * copy, modify, merge, publish, distribute, and/or sell copies of
- * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that either
- * (a) this copyright and permission notice appear with all copies
- * of the Data Files or Software, or
- * (b) this copyright and permission notice appear in associated
- * Documentation.
+ * NOTICE TO USER: Carefully read the following legal agreement. BY
+ * DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING DATA FILES, AND/OR
+ * SOFTWARE, YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
+ * TERMS AND CONDITIONS OF THIS AGREEMENT. IF YOU DO NOT AGREE, DO NOT
+ * DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE THE DATA FILES OR SOFTWARE.
  *
- * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
- * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
- * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
- * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
- * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
- * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
- * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
- * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
- * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
- * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
+ * Permission is hereby granted, free of charge, to any person obtaining a
+ * copy of data files and any associated documentation (the "Data Files") or
+ * software and any associated documentation (the "Software") to deal in the
+ * Data Files or Software without restriction, including without limitation
+ * the rights to use, copy, modify, merge, publish, distribute, and/or sell
+ * copies of the Data Files or Software, and to permit persons to whom the
+ * Data Files or Software are furnished to do so, provided that either (a)
+ * this copyright and permission notice appear with all copies of the Data
+ * Files or Software, or (b) this copyright and permission notice appear in
+ * associated Documentation.
  *
- * Except as contained in this notice, the name of a copyright holder
- * shall not be used in advertising or otherwise to promote the sale,
- * use or other dealings in these Data Files or Software without prior
- * written authorization of the copyright holder.
+ * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF ANY
+ * KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+ * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT OF
+ * THIRD PARTY RIGHTS.
+ *
+ * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS NOTICE
+ * BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL DAMAGES,
+ * OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS,
+ * WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION,
+ * ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THE DATA
+ * FILES OR SOFTWARE.
+ *
+ * Except as contained in this notice, the name of a copyright holder shall
+ * not be used in advertising or otherwise to promote the sale, use or other
+ * dealings in these Data Files or Software without prior written
+ * authorization of the copyright holder.
+ *
+ * SPDX-License-Identifier: Unicode-3.0
  */
 
 package sun.text.resources.cldr.ext;
@@ -66,7 +74,7 @@ import java.util.ListResourceBundle;
 public class FormatData_sr_Latn extends ListResourceBundle {
     @Override
     protected final Object[][] getContents() {
-        final String[] metaValue_generic_AmPmMarkers = new String[] {
+        final String[] metaValue_generic_narrow_AmPmMarkers = new String[] {
             "AM",
             "PM",
             "ponoć",
@@ -206,6 +214,7 @@ public class FormatData_sr_Latn extends ListResourceBundle {
         final String metaValue_generic_DateFormatItem_hmsv = "h:mm:ss a v";
         final String metaValue_generic_DateFormatItem_yw = "w. 'nedelja' 'u' Y.";
         final String metaValue_generic_DateFormatItem_yQQQ = "QQQ y.";
+        final String metaValue_generic_DateFormatItem_Hv = "HH 'h' v";
         final String metaValue_generic_DateFormatItem_MMMMEd = "E, d. MMMM";
         final String metaValue_generic_DateFormatItem_E = "E";
         final String metaValue_generic_DateFormatItem_MMMMd = "d. MMMM";
@@ -264,7 +273,6 @@ public class FormatData_sr_Latn extends ListResourceBundle {
             "Haisei",
             "Reiva",
         };
-        final String metaValue_buddhist_DateFormatItem_h = "h a";
         final String[] metaValue_java_time_roc_long_Eras = new String[] {
             "Pre RK",
             "RK",
@@ -273,6 +281,8 @@ public class FormatData_sr_Latn extends ListResourceBundle {
             "",
             "AH",
         };
+        final String metaValue_generic_DateFormatItem_GyMEd = "G dd. MM. y, E";
+        final String metaValue_generic_DateFormatItem_GyM = "M. y. G";
         final String metaValue_calendarname_gregorian = "gregorijanski kalendar";
         final String[] metaValue_ListPatterns_standard = new String[] {
             "",
@@ -294,9 +304,8 @@ public class FormatData_sr_Latn extends ListResourceBundle {
             { "generic.DayNarrows", metaValue_generic_DayNarrows },
             { "generic.QuarterNames", metaValue_generic_QuarterNames },
             { "generic.QuarterAbbreviations", metaValue_generic_QuarterAbbreviations },
-            { "generic.AmPmMarkers", metaValue_generic_AmPmMarkers },
-            { "generic.narrow.AmPmMarkers", metaValue_generic_AmPmMarkers },
-            { "generic.abbreviated.AmPmMarkers", metaValue_generic_AmPmMarkers },
+            { "generic.narrow.AmPmMarkers", metaValue_generic_narrow_AmPmMarkers },
+            { "generic.abbreviated.AmPmMarkers", metaValue_generic_narrow_AmPmMarkers },
             { "generic.TimePatterns", metaValue_generic_TimePatterns },
             { "java.time.generic.DatePatterns", metaValue_java_time_generic_DatePatterns },
             { "generic.DatePatterns", metaValue_generic_DatePatterns },
@@ -313,17 +322,20 @@ public class FormatData_sr_Latn extends ListResourceBundle {
             { "generic.DateFormatItem.hmsv", metaValue_generic_DateFormatItem_hmsv },
             { "generic.DateFormatItem.yw", metaValue_generic_DateFormatItem_yw },
             { "generic.DateFormatItem.yQQQ", metaValue_generic_DateFormatItem_yQQQ },
+            { "generic.DateFormatItem.Hv", metaValue_generic_DateFormatItem_Hv },
             { "generic.DateFormatItem.MMMMEd", metaValue_generic_DateFormatItem_MMMMEd },
             { "generic.DateFormatItem.yyyyMMM", metaValue_generic_DateFormatItem_yyyyMMM },
             { "generic.DateFormatItem.EBhm", "E hh:mm B" },
             { "generic.DateFormatItem.E", metaValue_generic_DateFormatItem_E },
             { "generic.DateFormatItem.MMMMd", metaValue_generic_DateFormatItem_MMMMd },
             { "generic.DateFormatItem.MMMEd", metaValue_generic_DateFormatItem_MMMEd },
+            { "generic.DateFormatItem.GyMEd", metaValue_generic_DateFormatItem_GyMEd },
             { "generic.DateFormatItem.GyMd", metaValue_generic_DateFormatItem_GyMd },
             { "generic.DateFormatItem.MMMd", metaValue_generic_DateFormatItem_MMMd },
             { "generic.DateFormatItem.MMMMW", metaValue_generic_DateFormatItem_MMMMW },
             { "generic.DateFormatItem.yyyy", metaValue_generic_DateFormatItem_Gy },
             { "generic.DateFormatItem.y", metaValue_generic_DateFormatItem_y },
+            { "generic.DateFormatItem.GyM", metaValue_generic_DateFormatItem_GyM },
             { "generic.DateFormatItem.GyMMM", metaValue_generic_DateFormatItem_yyyyMMM },
             { "generic.DateFormatItem.yMMMEd", metaValue_generic_DateFormatItem_yMMMEd },
             { "generic.DateFormatItem.Ehms", metaValue_generic_DateFormatItem_Ehms },
@@ -370,9 +382,9 @@ public class FormatData_sr_Latn extends ListResourceBundle {
             { "standalone.QuarterAbbreviations", metaValue_generic_QuarterAbbreviations },
             { "QuarterNarrows", metaValue_QuarterNarrows },
             { "standalone.QuarterNarrows", metaValue_QuarterNarrows },
-            { "AmPmMarkers", metaValue_generic_AmPmMarkers },
-            { "narrow.AmPmMarkers", metaValue_generic_AmPmMarkers },
-            { "abbreviated.AmPmMarkers", metaValue_generic_AmPmMarkers },
+            { "AmPmMarkers", metaValue_generic_narrow_AmPmMarkers },
+            { "narrow.AmPmMarkers", metaValue_generic_narrow_AmPmMarkers },
+            { "abbreviated.AmPmMarkers", metaValue_generic_narrow_AmPmMarkers },
             { "java.time.long.Eras", metaValue_java_time_long_Eras },
             { "long.Eras", metaValue_java_time_long_Eras },
             { "java.time.Eras", metaValue_java_time_Eras },
@@ -410,6 +422,7 @@ public class FormatData_sr_Latn extends ListResourceBundle {
             { "DateFormatItem.hmsv", metaValue_generic_DateFormatItem_hmsv },
             { "DateFormatItem.yw", metaValue_generic_DateFormatItem_yw },
             { "DateFormatItem.yQQQ", metaValue_generic_DateFormatItem_yQQQ },
+            { "DateFormatItem.Hv", metaValue_generic_DateFormatItem_Hv },
             { "DateFormatItem.MMMMEd", metaValue_generic_DateFormatItem_MMMMEd },
             { "DateFormatItem.E", metaValue_generic_DateFormatItem_E },
             { "DateFormatItem.MMMMd", metaValue_generic_DateFormatItem_MMMMd },
@@ -445,9 +458,9 @@ public class FormatData_sr_Latn extends ListResourceBundle {
             { "buddhist.DayAbbreviations", metaValue_generic_DayAbbreviations },
             { "buddhist.QuarterNames", metaValue_generic_QuarterNames },
             { "buddhist.QuarterAbbreviations", metaValue_generic_QuarterAbbreviations },
-            { "buddhist.AmPmMarkers", metaValue_generic_AmPmMarkers },
-            { "buddhist.narrow.AmPmMarkers", metaValue_generic_AmPmMarkers },
-            { "buddhist.abbreviated.AmPmMarkers", metaValue_generic_AmPmMarkers },
+            { "buddhist.AmPmMarkers", metaValue_generic_narrow_AmPmMarkers },
+            { "buddhist.narrow.AmPmMarkers", metaValue_generic_narrow_AmPmMarkers },
+            { "buddhist.abbreviated.AmPmMarkers", metaValue_generic_narrow_AmPmMarkers },
             { "java.time.buddhist.long.Eras", metaValue_java_time_buddhist_long_Eras },
             { "buddhist.long.Eras", metaValue_java_time_buddhist_long_Eras },
             { "java.time.buddhist.Eras", metaValue_java_time_buddhist_long_Eras },
@@ -466,11 +479,11 @@ public class FormatData_sr_Latn extends ListResourceBundle {
             { "buddhist.DateFormatItem.hmsv", metaValue_generic_DateFormatItem_hmsv },
             { "buddhist.DateFormatItem.yw", metaValue_generic_DateFormatItem_yw },
             { "buddhist.DateFormatItem.yQQQ", metaValue_generic_DateFormatItem_yQQQ },
+            { "buddhist.DateFormatItem.Hv", metaValue_generic_DateFormatItem_Hv },
             { "buddhist.DateFormatItem.MMMMEd", metaValue_generic_DateFormatItem_MMMMEd },
             { "buddhist.DateFormatItem.E", metaValue_generic_DateFormatItem_E },
             { "buddhist.DateFormatItem.MMMMd", metaValue_generic_DateFormatItem_MMMMd },
             { "buddhist.DateFormatItem.MMMEd", metaValue_generic_DateFormatItem_MMMEd },
-            { "buddhist.DateFormatItem.h", metaValue_buddhist_DateFormatItem_h },
             { "buddhist.DateFormatItem.GyMd", metaValue_generic_DateFormatItem_GyMd },
             { "buddhist.DateFormatItem.MMMd", metaValue_generic_DateFormatItem_MMMd },
             { "buddhist.DateFormatItem.MMMMW", metaValue_generic_DateFormatItem_MMMMW },
@@ -503,9 +516,8 @@ public class FormatData_sr_Latn extends ListResourceBundle {
             { "japanese.QuarterNames", metaValue_generic_QuarterNames },
             { "japanese.QuarterAbbreviations", metaValue_generic_QuarterAbbreviations },
             { "japanese.QuarterNarrows", metaValue_QuarterNarrows },
-            { "japanese.AmPmMarkers", metaValue_generic_AmPmMarkers },
-            { "japanese.narrow.AmPmMarkers", metaValue_generic_AmPmMarkers },
-            { "japanese.abbreviated.AmPmMarkers", metaValue_generic_AmPmMarkers },
+            { "japanese.AmPmMarkers", metaValue_generic_narrow_AmPmMarkers },
+            { "japanese.abbreviated.AmPmMarkers", metaValue_generic_narrow_AmPmMarkers },
             { "java.time.japanese.long.Eras", metaValue_java_time_japanese_long_Eras },
             { "japanese.long.Eras", metaValue_java_time_japanese_long_Eras },
             { "java.time.japanese.Eras", metaValue_java_time_japanese_Eras },
@@ -536,11 +548,11 @@ public class FormatData_sr_Latn extends ListResourceBundle {
             { "japanese.DateFormatItem.hmsv", metaValue_generic_DateFormatItem_hmsv },
             { "japanese.DateFormatItem.yw", metaValue_generic_DateFormatItem_yw },
             { "japanese.DateFormatItem.yQQQ", metaValue_generic_DateFormatItem_yQQQ },
+            { "japanese.DateFormatItem.Hv", metaValue_generic_DateFormatItem_Hv },
             { "japanese.DateFormatItem.MMMMEd", metaValue_generic_DateFormatItem_MMMMEd },
             { "japanese.DateFormatItem.E", metaValue_generic_DateFormatItem_E },
             { "japanese.DateFormatItem.MMMMd", metaValue_generic_DateFormatItem_MMMMd },
             { "japanese.DateFormatItem.MMMEd", metaValue_generic_DateFormatItem_MMMEd },
-            { "japanese.DateFormatItem.h", metaValue_buddhist_DateFormatItem_h },
             { "japanese.DateFormatItem.GyMd", metaValue_generic_DateFormatItem_GyMd },
             { "japanese.DateFormatItem.MMMd", metaValue_generic_DateFormatItem_MMMd },
             { "japanese.DateFormatItem.MMMMW", metaValue_generic_DateFormatItem_MMMMW },
@@ -574,9 +586,7 @@ public class FormatData_sr_Latn extends ListResourceBundle {
             { "roc.QuarterNames", metaValue_generic_QuarterNames },
             { "roc.QuarterAbbreviations", metaValue_generic_QuarterAbbreviations },
             { "roc.QuarterNarrows", metaValue_QuarterNarrows },
-            { "roc.AmPmMarkers", metaValue_generic_AmPmMarkers },
-            { "roc.narrow.AmPmMarkers", metaValue_generic_AmPmMarkers },
-            { "roc.abbreviated.AmPmMarkers", metaValue_generic_AmPmMarkers },
+            { "roc.abbreviated.AmPmMarkers", metaValue_generic_narrow_AmPmMarkers },
             { "java.time.roc.long.Eras", metaValue_java_time_roc_long_Eras },
             { "roc.long.Eras", metaValue_java_time_roc_long_Eras },
             { "java.time.roc.Eras", metaValue_java_time_roc_long_Eras },
@@ -595,11 +605,11 @@ public class FormatData_sr_Latn extends ListResourceBundle {
             { "roc.DateFormatItem.hmsv", metaValue_generic_DateFormatItem_hmsv },
             { "roc.DateFormatItem.yw", metaValue_generic_DateFormatItem_yw },
             { "roc.DateFormatItem.yQQQ", metaValue_generic_DateFormatItem_yQQQ },
+            { "roc.DateFormatItem.Hv", metaValue_generic_DateFormatItem_Hv },
             { "roc.DateFormatItem.MMMMEd", metaValue_generic_DateFormatItem_MMMMEd },
             { "roc.DateFormatItem.E", metaValue_generic_DateFormatItem_E },
             { "roc.DateFormatItem.MMMMd", metaValue_generic_DateFormatItem_MMMMd },
             { "roc.DateFormatItem.MMMEd", metaValue_generic_DateFormatItem_MMMEd },
-            { "roc.DateFormatItem.h", metaValue_buddhist_DateFormatItem_h },
             { "roc.DateFormatItem.GyMd", metaValue_generic_DateFormatItem_GyMd },
             { "roc.DateFormatItem.MMMd", metaValue_generic_DateFormatItem_MMMd },
             { "roc.DateFormatItem.MMMMW", metaValue_generic_DateFormatItem_MMMMW },
@@ -663,9 +673,7 @@ public class FormatData_sr_Latn extends ListResourceBundle {
             { "islamic.DayAbbreviations", metaValue_generic_DayAbbreviations },
             { "islamic.QuarterNames", metaValue_generic_QuarterNames },
             { "islamic.QuarterAbbreviations", metaValue_generic_QuarterAbbreviations },
-            { "islamic.AmPmMarkers", metaValue_generic_AmPmMarkers },
-            { "islamic.narrow.AmPmMarkers", metaValue_generic_AmPmMarkers },
-            { "islamic.abbreviated.AmPmMarkers", metaValue_generic_AmPmMarkers },
+            { "islamic.abbreviated.AmPmMarkers", metaValue_generic_narrow_AmPmMarkers },
             { "java.time.islamic.long.Eras", metaValue_java_time_islamic_long_Eras },
             { "islamic.long.Eras", metaValue_java_time_islamic_long_Eras },
             { "java.time.islamic.Eras", metaValue_java_time_islamic_long_Eras },
@@ -684,15 +692,17 @@ public class FormatData_sr_Latn extends ListResourceBundle {
             { "islamic.DateFormatItem.hmsv", metaValue_generic_DateFormatItem_hmsv },
             { "islamic.DateFormatItem.yw", metaValue_generic_DateFormatItem_yw },
             { "islamic.DateFormatItem.yQQQ", metaValue_generic_DateFormatItem_yQQQ },
+            { "islamic.DateFormatItem.Hv", metaValue_generic_DateFormatItem_Hv },
             { "islamic.DateFormatItem.MMMMEd", metaValue_generic_DateFormatItem_MMMMEd },
             { "islamic.DateFormatItem.E", metaValue_generic_DateFormatItem_E },
             { "islamic.DateFormatItem.MMMMd", metaValue_generic_DateFormatItem_MMMMd },
             { "islamic.DateFormatItem.MMMEd", metaValue_generic_DateFormatItem_MMMEd },
-            { "islamic.DateFormatItem.h", metaValue_buddhist_DateFormatItem_h },
+            { "islamic.DateFormatItem.GyMEd", metaValue_generic_DateFormatItem_GyMEd },
             { "islamic.DateFormatItem.GyMd", metaValue_generic_DateFormatItem_GyMd },
             { "islamic.DateFormatItem.MMMd", metaValue_generic_DateFormatItem_MMMd },
             { "islamic.DateFormatItem.MMMMW", metaValue_generic_DateFormatItem_MMMMW },
             { "islamic.DateFormatItem.y", metaValue_generic_DateFormatItem_y },
+            { "islamic.DateFormatItem.GyM", metaValue_generic_DateFormatItem_GyM },
             { "islamic.DateFormatItem.GyMMM", metaValue_generic_DateFormatItem_yyyyMMM },
             { "islamic.DateFormatItem.yMMMEd", metaValue_generic_DateFormatItem_yMMMEd },
             { "islamic.DateFormatItem.Ehms", metaValue_generic_DateFormatItem_Ehms },
@@ -723,11 +733,11 @@ public class FormatData_sr_Latn extends ListResourceBundle {
             { "islamic-civil.DateFormatItem.hmsv", metaValue_generic_DateFormatItem_hmsv },
             { "islamic-civil.DateFormatItem.yw", metaValue_generic_DateFormatItem_yw },
             { "islamic-civil.DateFormatItem.yQQQ", metaValue_generic_DateFormatItem_yQQQ },
+            { "islamic-civil.DateFormatItem.Hv", metaValue_generic_DateFormatItem_Hv },
             { "islamic-civil.DateFormatItem.MMMMEd", metaValue_generic_DateFormatItem_MMMMEd },
             { "islamic-civil.DateFormatItem.E", metaValue_generic_DateFormatItem_E },
             { "islamic-civil.DateFormatItem.MMMMd", metaValue_generic_DateFormatItem_MMMMd },
             { "islamic-civil.DateFormatItem.MMMEd", metaValue_generic_DateFormatItem_MMMEd },
-            { "islamic-civil.DateFormatItem.h", metaValue_buddhist_DateFormatItem_h },
             { "islamic-civil.DateFormatItem.GyMd", metaValue_generic_DateFormatItem_GyMd },
             { "islamic-civil.DateFormatItem.MMMd", metaValue_generic_DateFormatItem_MMMd },
             { "islamic-civil.DateFormatItem.MMMMW", metaValue_generic_DateFormatItem_MMMMW },
@@ -762,11 +772,11 @@ public class FormatData_sr_Latn extends ListResourceBundle {
             { "islamic-umalqura.DateFormatItem.hmsv", metaValue_generic_DateFormatItem_hmsv },
             { "islamic-umalqura.DateFormatItem.yw", metaValue_generic_DateFormatItem_yw },
             { "islamic-umalqura.DateFormatItem.yQQQ", metaValue_generic_DateFormatItem_yQQQ },
+            { "islamic-umalqura.DateFormatItem.Hv", metaValue_generic_DateFormatItem_Hv },
             { "islamic-umalqura.DateFormatItem.MMMMEd", metaValue_generic_DateFormatItem_MMMMEd },
             { "islamic-umalqura.DateFormatItem.E", metaValue_generic_DateFormatItem_E },
             { "islamic-umalqura.DateFormatItem.MMMMd", metaValue_generic_DateFormatItem_MMMMd },
             { "islamic-umalqura.DateFormatItem.MMMEd", metaValue_generic_DateFormatItem_MMMEd },
-            { "islamic-umalqura.DateFormatItem.h", metaValue_buddhist_DateFormatItem_h },
             { "islamic-umalqura.DateFormatItem.GyMd", metaValue_generic_DateFormatItem_GyMd },
             { "islamic-umalqura.DateFormatItem.MMMd", metaValue_generic_DateFormatItem_MMMd },
             { "islamic-umalqura.DateFormatItem.MMMMW", metaValue_generic_DateFormatItem_MMMMW },
